// file.cc - File Interface
// GPLed - Stephan T. Lavavej - http://stl.caltech.edu

#include "file.hh"

// PURPOSE: Return the size of a given binary file
// NOTE:    Does not change position of file
long int file_size(FILE *fp) {

    long int orig = ftell(fp);
    fseek(fp, 0, SEEK_END);
    long int size = ftell(fp);
    fseek(fp, orig, SEEK_SET);
    return size;
}

// PURPOSE: Close a file safely
void file_close(FILE *fp) {
    if (fclose(fp) == EOF) {
        cout << "ERROR: Problem while closing file." << endl;
        exit(EXIT_FAILURE);
    }
}

// PURPOSE: Open a file for binary read safely
// RETURN:  The file pointer
FILE * file_open_rb(const char *name) {

    FILE *fp = NULL;

    fp = fopen(name, "rb");

    if (fp == NULL) {
        cout << "ERROR: Cannot open " << name << " for input." << endl;
        exit(EXIT_FAILURE);
    }

    return fp;
}

// PURPOSE: Open a file for binary write safely
// RETURN:  The file pointer
FILE * file_open_wb(const char *name) {

    FILE *fp = NULL;

    fp = fopen(name, "rb");

    if (fp  != NULL) {
        cout << "ERROR: Output file " << name << " already exists." << endl;
        exit(EXIT_FAILURE);
    }

    fp = fopen(name, "wb");

    if (fp == NULL) {
        cout << "ERROR: Cannot open file " << name << " for output." << endl;
        exit(EXIT_FAILURE);
    }

    return fp;
}

